from django.urls import re_path
from rest_framework.routers import SimpleRouter

from . import views

r = SimpleRouter(trailing_slash=False)

r.register(r"users", views.UserViewSet)
r.register(r"scopes", views.ScopeViewSet)
r.register(r"roles", views.RoleViewSet)
r.register(r"permissions", views.PermissionViewSet)
r.register(r"acls", views.ACLViewSet)

urlpatterns = [
    re_path(r"^me", views.MeViewSet.as_view({"get": "retrieve"}), name="me-detail"),
    re_path(
        r"^myacls/(?P<pk>[^/.]+)$",
        views.MyACLViewSet.as_view({"get": "retrieve"}),
        name="myacls-detail",
    ),
    re_path(
        r"^myacls", views.MyACLViewSet.as_view({"get": "list"}), name="myacls-list"
    ),
]

urlpatterns.extend(r.urls)



# Generated by Django 2.2.24 on 2021-07-22 12:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("emeis_core", "0003_localized_city"),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="last_login",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="last login"
            ),
        ),
        migrations.AddField(
            model_name="user",
            name="password",
            field=models.CharField(default="", max_length=128, verbose_name="password"),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.12 on 2022-02-02 16:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("emeis_core", "0006_rename_field_meta_metainfo"),
    ]

    operations = [
        migrations.AlterField(
            model_name="acl",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="permission",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="role",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="scope",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="user",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
    ]
